#!@@SH@@
#
# opkbuild
# src/ob-applypatches.sh
# Apply patches to source code.
#
# Copyright (C) 2012 Patrick "P. J." McDermott
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

. '@@PKGLIBDIR@@/load.sm'

ob_use locale
ob_use output
ob_use package

main()
{
	ob_set_text_domain 'opkbuild'

	ob_init_package '..' || exit 1
	ob_parse_package_metadata -c '.opkbuild.cache' || exit 1

	apply_patches
}

apply_patches()
{
	applied='false'

	if [ -d '../patches' ] && [ -d 'src' ]; then
		# Iterate over patches ordered alphabetically by name.
		# POSIX.1-2008 says that the results of a pathname expansion shall be
		# "sorted according to the collating sequence in effect in the current
		# locale".  So for consistent results, we first set a standard locale.
		orig_lang="${LANG}"
		LANG='POSIX'
		for patch in '../patches/'*; do
			[ -f "${patch}" ] || continue
			LANG="${orig_lang}"
			patch="${patch#../patches/}"
			ob_info "$(ob_get_msg 'applying_patch')" "${patch}"
			cd src
			patch -N -p 1 -u -i "../../patches/${patch}" || \
				ob_error "$(ob_get_msg 'cant_apply_patch')" "${patch}"
			cd ..
			applied='true'
		done
		LANG="${orig_lang}"
	fi

	${applied} || ob_info "$(ob_get_msg 'no_patches')"
}

main "${@}"
